#!/usr/bin/env python

# -*- coding: ascii -*-

import sys
import os
import subprocess
try:
    cmd = './configure --prefix=`pwd`/dist '
    for arg in sys.argv[1:]:
        a = arg.split('=')
        if len(a) == 2:
            s = '%s="%s"' % (a[0],a[1])
        else:
            s = a[0]
        cmd += (s + ' ')
    cmd += '&& make install'        
    r = subprocess.call(cmd, shell=1)
    if r < 0:
        print >>sys.stderr, 'child terminated by signal', -r
except OSError, e:
    print >>sys.stderr, 'execution failed', e
except KeyboardInterrupt:
    print
